/*
 * Copyright The OpenTelemetry Authors
 * SPDX-License-Identifier: Apache-2.0
 */

package io.opentelemetry.sdk.trace;

import io.opentelemetry.sdk.common.CompletableResultCode;

final class NoopSpanProcessor implements SpanProcessor {
  private static final NoopSpanProcessor INSTANCE = new NoopSpanProcessor();

  static SpanProcessor getInstance() {
    return INSTANCE;
  }

  @Override
  public void onStart(ReadWriteSpan span) {}

  @Override
  public boolean isStartRequired() {
    return false;
  }

  @Override
  public void onEnd(ReadableSpan span) {}

  @Override
  public boolean isEndRequired() {
    return false;
  }

  @Override
  public CompletableResultCode shutdown() {
    return CompletableResultCode.ofSuccess();
  }

  @Override
  public CompletableResultCode forceFlush() {
    return CompletableResultCode.ofSuccess();
  }

  private NoopSpanProcessor() {}
}
